pub enum TryFromError {
u32(&'static str, u32),
u16(&'static str, u16),
u8(&'static str, u8),
usize(&'static str, usize),
}Expand description
Error produced by the enum try_from macros
Variants
u32(&'static str, u32)
A u32 value (second field) is out of range for the named enum (first field).
u16(&'static str, u16)
A u16 value (second field) is out of range for the named enum (first field).
u8(&'static str, u8)
A u8 value (second field) is out of range for the named enum (first field).
usize(&'static str, usize)
A usize value (second field) is out of range for the named enum (first field).