Module env

Module env 

Access to environment variables when running natively or on top of Node.js (via process.env).

Functions

var
Returns the value of the environment variable _key, reading from the process environment natively or from process.env under Node.js. Returns VarError::NotPresent if the variable is unset.