Module fd

Module fd 

Module for the file descriptor limit management.

Functions

limit
Returns the current open file descriptor limit for the process, or an error on platforms where the limit cannot be queried.
try_set_fd_limit