Module hex

Module hex 

Hex serialization traits

Traits

FromHex
Trait for types that can be parsed from a hexadecimal string.
ToHex
Trait for types that can render themselves as a hexadecimal string.

Functions

deserialize
serde deserialize helper that decodes a hex string into a FromHex value.
serialize
serde serialize helper that encodes a ToHex value as a hex string.