Module prelude

Module prelude 

The prelude module re-exports the most commonly used traits and types from the workflow_core crate.

Re-exports

pub use crate::abortable::Abortable;
pub use crate::channel::Channel;
pub use crate::channel::DuplexChannel;
pub use crate::channel::Multiplexer;
pub use crate::channel::oneshot;
pub use crate::enums::Describe;
pub use crate::sendable::Sendable;
pub use crate::task::dispatch;
pub use crate::task::interval;
pub use crate::task::spawn;
pub use crate::time::unixtime_as_millis_f64;
pub use crate::time::unixtime_as_millis_u128;
pub use crate::extensions::*;

Structs

Duration
re-export of [instant] crate supporting native and WASM implementations A Duration type to represent a span of time, typically used for system timeouts.
Instant
re-export of [instant] crate supporting native and WASM implementations A measurement of a monotonically nondecreasing clock. Opaque and useful only with Duration.

Functions

sleep
Waits until duration has elapsed.
yield_executor
Yields execution back to the Tokio runtime.
yield_now
Yields execution back to the Tokio runtime.

Derive Macros

Describe
Attribute macro for automatic conversion of enums to their string representation