Module for the file descriptor limit management.
Functions
- limit
- Returns the current open file descriptor limit for the process, or an error on platforms where the limit cannot be queried.
- try_
set_ fd_ limit
Module for the file descriptor limit management.