Hex serialization traits
Traits
- FromHex
- Trait for types that can be parsed from a hexadecimal string.
- ToHex
- Trait for types that can render themselves as a hexadecimal string.
Functions
- deserialize
serdedeserialize helper that decodes a hex string into aFromHexvalue.- serialize
serdeserialize helper that encodes aToHexvalue as a hex string.