Provides functions that allow to detect the runtime environment. These functions can be used to detect whether the code is running in a browser, node.js or native OS, the type of the underlying OS (Windows,Linux,MacOS,*BSD) as well as the type of a web environment (Browser or NWJS). This is useful for an application of an API to detect which environment it is operating under and subsequently restrict the functionality to the capabilities to this environment.
Enums
- Platform
- Operating system / platform on which the application is running.
- Runtime
- application runtime info
Functions
- is_
android - Returns
trueif the current platform is Android. - is_
chrome_ extension - Returns
trueif the application is running as a Chrome browser extension. - is_
cross_ origin_ isolated - Helper to test whether the application is running in a cross-origin isolated browser environment (Flutter).
- is_
electron - Helper to test whether the application is running under Electron.
- is_
electron_ client - Helper to test whether the application is running under Electron backend.
- is_
electron_ server - Helper to test whether the application is running under Electron backend.
- is_
freebsd - Returns
trueif the current platform is FreeBSD. - is_ios
- Returns
trueif the current platform is iOS. - is_
linux - Returns
trueif the current platform is Linux. - is_
macos - Returns
trueif the current platform is macOS. - is_
mobile - Returns
trueif the current platform is a mobile OS (iOS or Android). - is_
native - Helper to test whether the application is running under native runtime which is not a Solana OS and architecture is not WASM32
- is_
netbsd - Returns
trueif the current platform is NetBSD. - is_node
- Helper to test whether the application is running under NodeJs-compatible environment.
- is_nw
- Helper to test whether the application is running under NW environment.
- is_
openbsd - Returns
trueif the current platform is OpenBSD. - is_
solana - Helper to test whether the application is running under Solana OS.
- is_unix
- Returns
trueif the current platform is a Unix-like OS (macOS, Linux, or a BSD). - is_wasm
- Helper to test (at runtime) whether the application is running under WASM32 architecture.
- is_web
- Helper to test whether the application is running under in a regular browser environment.
- is_
web_ capable - Identifies web-capable environment (browser, NWJS window, Electron client)
- is_
windows - Returns
trueif the current platform is Windows. - platform
- Detects and returns the
Platformthe application is running on, caching the result on first call.